@@ -185,7 +185,6 @@ class WatchTowerHandler(logging.Handler):
 
     def _wt_worker(self, payload=None):
         self.write_debug_log("_wt_worker() called")
-
         if self.flush_interval > 0:
             # Stop the timer. Happens automatically if this is called
             # via the timer, does not if invoked by force_flush()
@@ -207,7 +206,10 @@ class WatchTowerHandler(logging.Handler):
                 if self.token:
                     headers.update({'Authorization': f'Token {self.token}'})
 
+                payload = f'[{payload}]'
+
                 self.write_debug_log("Sending payload: " + payload)
+
                 r = self.session.post(
                     self.url,
                     data=payload,
@@ -254,14 +256,14 @@ class WatchTowerHandler(logging.Handler):
 
         self.write_debug_log("Recursing through queue")
         if self.SIGTERM:
-            self.log_payload += ''.join(self.queue)
+            self.log_payload += ','.join(self.queue)
             self.queue.clear()
         else:
             # without looking at each item, estimate how many can fit in 50 MB
             apprx_size_base = len(self.queue[0])
             # dont count more than what is in queue to ensure the same number as pulled are deleted
             count = min(int(524288 / apprx_size_base), len(self.queue))
-            self.log_payload += ''.join(self.queue[:count])
+            self.log_payload += ','.join(self.queue[:count])
             del self.queue[:count]
         self.write_debug_log("Queue task completed")
 
