@@ -34,7 +34,8 @@ def logaction(self, msg, lvl_num, args, data=None, **kws):
     if self.isEnabledFor(lvl_num):
         if not data is None:
             if lvl_num >= logLevels.ERROR:
-                data['traceback'] = traceback.format_exc()
+                if not 'traceback' in data:
+                    data['traceback'] = traceback.format_exc()
 
             if 'extra' in kws:
                 if 'data' in kws['extra']:
@@ -109,7 +110,7 @@ class CustomJsonFormatter(jsonlogger.JsonFormatter):
 
 
 def getLogger(beam_id, name=None, execution_id=None, token=None, host=None, protocol=None, dev=False,
-              level=logLevels.START, debug=False, path=None, console=False, send=True, use_threading=None):
+              level=logLevels.START, debug=False, path=None, console=False, send=True, use_threading=None, catch_all=True):
 
     # create logger
     name = name or os.environ.get('FUNCTION_NAME', 'watchtower-logging')
@@ -176,6 +177,20 @@ def getLogger(beam_id, name=None, execution_id=None, token=None, host=None, prot
             ch.setFormatter(c_formatter)
             logger.addHandler(ch)
 
+    if catch_all:
+
+        import sys
+
+        def watchtower_handle_exception(exc_type, exc_value, exc_traceback):
+            if issubclass(exc_type, KeyboardInterrupt):
+                sys.__excepthook__(exc_type, exc_value, exc_traceback)
+                return
+
+            logger.critical('Uncaught Exception', data={'traceback': f'{exc_type.__name__}: {exc_value}\n{"".join(traceback.format_tb(exc_traceback))}'})
+            sys.__excepthook__(exc_type, exc_value, exc_traceback)
+
+        sys.excepthook = watchtower_handle_exception
+
     logger.setExecutionId(execution_id=execution_id)
 
     return logger
\ No newline at end of file
